@@ -15,25 +15,26 @@ stop_if_not <- function(...) {
 }
 
 eof_ok <- function(file) {
-  size <- file.info(file)$size
-  ## On Windows, symbolic links give size = 0
+  size <- file_size(file)
+  ## On Windows, symbolic links, e.g. by file.symlink(), give size = 0
+  ## although below readBin() return a non-empty vector
   if (.Platform$OS.type == "windows" && size == 0L) size <- 1e9
   bfr <- readBin(file, what = "raw", n = size)
   n <- length(bfr)
-  if (n == 0L) return(FALSE)
+  if (n == 0L) return(TRUE)
   is.element(bfr[n], charToRaw("\n\r"))
 }
 
 is_dir <- function(f) {
   if (length(f) != 1L) {
-    stop(sprintf("INTERNAL ERROR in startup:::is_dir(): only scalar input is supported: [n=%d] %s", length(f), paste(sQuote(f), collapse = ", ")))
+    stop(sprintf("INTERNAL ERROR in startup:::is_dir(): only scalar input is supported: [n=%d] %s", length(f), paste(squote(f), collapse = ", ")))
   }
   nzchar(f) && file.exists(f) && file.info(f)$isdir
 }
 
 is_file <- function(f) {
   if (length(f) != 1L) {
-    stop(sprintf("INTERNAL ERROR in startup:::is_file(): only scalar input is supported: [n=%d] %s", length(f), paste(sQuote(f), collapse = ", ")))
+    stop(sprintf("INTERNAL ERROR in startup:::is_file(): only scalar input is supported: [n=%d] %s", length(f), paste(squote(f), collapse = ", ")))
   }
   nzchar(f) && file.exists(f) && !file.info(f)$isdir
 }
@@ -51,7 +52,7 @@ nlines <- function(f) {
 file_size <- function(...) file.info(..., extra_cols = FALSE)$size
 
 path_info <- function(f, extra = NULL) {
-  if (!nzchar(f)) return(sQuote(""))
+  if (!nzchar(f)) return(squote(""))
   fx <- path.expand(f)
   if (!is.null(extra)) {
     extra <- paste("; ", extra, sep = "")
@@ -60,19 +61,19 @@ path_info <- function(f, extra = NULL) {
   }
 
   if (!is_dir(f)) {
-    return(sprintf("%s (non-existing directory%s)", sQuote(f), extra))
+    return(sprintf("%s (non-existing directory%s)", squote(f), extra))
   }
 
   if (fx == f) {
-    sprintf("%s (existing folder%s)", sQuote(f), extra)
+    sprintf("%s (existing folder%s)", squote(f), extra)
   } else {
-    sprintf("%s => %s (existing folder%s)", sQuote(f), sQuote(fx), extra)
+    sprintf("%s => %s (existing folder%s)", squote(f), squote(fx), extra)
   }
 }
 
 
-file_info <- function(f, type = "txt", extra = NULL) {
-  if (!nzchar(f)) return(sQuote(""))
+file_info <- function(f, type = "txt", extra = NULL, validate = FALSE) {
+  if (!nzchar(f)) return(squote(""))
   fx <- path.expand(f)
   if (length(extra) > 0L) {
     extra <- paste("; ", extra, sep = "")
@@ -80,21 +81,25 @@ file_info <- function(f, type = "txt", extra = NULL) {
     extra <- ""
   }
   if (!is_file(f)) {
-    return(sprintf("%s (non-existing file%s)", sQuote(f), extra))
+    return(sprintf("%s (non-existing file%s)", squote(f), extra))
   }
 
   if (fx == f) {
-    prefix <- sQuote(f)
+    prefix <- squote(f)
   } else {
-    prefix <- sprintf("%s => %s", sQuote(f), sQuote(fx))
+    prefix <- sprintf("%s => %s", squote(f), squote(fx))
   }
   if (type == "binary") {
     sprintf("%s (binary file; %d bytes%s)", prefix, file_size(f), extra)
   } else if (type == "env") {
+    warn <- NULL
     vars <- names(parse_renviron(f))
     nvars <- length(vars)
     if (nvars > 0) {
-      vars <- sprintf(" (%s)", paste(sQuote(vars), collapse = ", "))
+      if (validate && !any(vars %in% names(Sys.getenv()))) {
+        prefix <- sprintf("[WARNING: It appears that R never processed this file] %s", prefix)
+      }
+      vars <- sprintf(" (%s)", paste(squote(vars), collapse = ", "))
     } else {
       vars <- ""
     }
@@ -132,6 +137,12 @@ find <- function(what, mode) {
   -1L
 }
 
+## sQuote() without fancy quotes, if possible
+squote <- if (getRversion() >= "3.6.0") {
+  function(x) sQuote(x, q = FALSE)
+} else {
+  function(x) sQuote(x)
+}
 
 supports_tcltk <- function() {
   (capabilities("X11") && capabilities("tcltk") &&
@@ -140,7 +151,7 @@ supports_tcltk <- function() {
 
 tcltk_yesno <- function(question) {
   if (!supports_tcltk()) {
-    warning("[startup::startup()]: Your R setup does not support X11 or tcltk dialogs. Because of this, the answer to the question ", sQuote(question), " was defaulted to 'yes'.", call. = FALSE)
+    warning("[startup::startup()]: Your R setup does not support X11 or tcltk dialogs. Because of this, the answer to the question ", sQuote(question), " was defaulted to ", sQuote("yes"), ".", call. = FALSE)
     return(TRUE)
   }  
   ans <- tcltk::tk_messageBox("yesno", message = question)
@@ -185,4 +196,4 @@ ask_yes_no <- function(question, rdata_workaround = TRUE) {
   })
 
   res
-}
\ No newline at end of file
+}
